@@ -38,7 +38,7 @@ COLD void bitfn(dav1d_loop_filter_dsp_init_arm)(Dav1dLoopFilterDSPContext *const
 
     if (!(flags & DAV1D_ARM_CPU_FLAG_NEON)) return;
 
-#if BITDEPTH == 8 && ARCH_AARCH64
+#if BITDEPTH == 8
     c->loop_filter_sb[0][0] = dav1d_lpf_h_sb_y_neon;
     c->loop_filter_sb[0][1] = dav1d_lpf_v_sb_y_neon;
     c->loop_filter_sb[1][0] = dav1d_lpf_h_sb_uv_neon;
