@@ -33,6 +33,7 @@
 #include <string.h>
 
 #include "common/attributes.h"
+#include "common/intops.h"
 
 #include "input/input.h"
 #include "input/demuxer.h"
@@ -42,7 +43,7 @@ struct DemuxerContext {
     const Demuxer *impl;
 };
 
-#define MAX_NUM_DEMUXERS 2
+#define MAX_NUM_DEMUXERS 3
 static const Demuxer *demuxers[MAX_NUM_DEMUXERS];
 static int num_demuxers = 0;
 
@@ -55,23 +56,7 @@ static int num_demuxers = 0;
 void init_demuxers(void) {
     register_demuxer(ivf_demuxer);
     register_demuxer(annexb_demuxer);
-}
-
-static const char *find_extension(const char *const f) {
-    const size_t l = strlen(f);
-
-    if (l == 0) return NULL;
-
-    const char *const end = &f[l - 1], *step = end;
-    while ((*step >= 'a' && *step <= 'z') ||
-           (*step >= 'A' && *step <= 'Z') ||
-           (*step >= '0' && *step <= '9'))
-    {
-        step--;
-    }
-
-    return (step < end && step > f && *step == '.' && step[-1] != '/') ?
-           &step[1] : NULL;
+    register_demuxer(section5_demuxer);
 }
 
 int input_open(DemuxerContext **const c_out,
@@ -94,22 +79,34 @@ int input_open(DemuxerContext **const c_out,
             return DAV1D_ERR(ENOPROTOOPT);
         }
     } else {
-        const char *const ext = find_extension(filename);
-        if (!ext) {
-            fprintf(stderr, "No extension found for file %s\n", filename);
-            return -1;
+        int probe_sz = 0;
+        for (i = 0; i < num_demuxers; i++)
+            probe_sz = imax(probe_sz, demuxers[i]->probe_sz);
+        uint8_t *const probe_data = malloc(probe_sz);
+        if (!probe_data) {
+            fprintf(stderr, "Failed to allocate memory\n");
+            return DAV1D_ERR(ENOMEM);
+        }
+        FILE *f = fopen(filename, "rb");
+        res = !!fread(probe_data, 1, probe_sz, f);
+        fclose(f);
+        if (!res) {
+            free(probe_data);
+            fprintf(stderr, "Failed to read probe data\n");
+            return errno ? DAV1D_ERR(errno) : DAV1D_ERR(EIO);
         }
 
         for (i = 0; i < num_demuxers; i++) {
-            if (!strcmp(demuxers[i]->extension, ext)) {
+            if (demuxers[i]->probe(probe_data)) {
                 impl = demuxers[i];
                 break;
             }
         }
+        free(probe_data);
         if (i == num_demuxers) {
             fprintf(stderr,
-                    "Failed to find demuxer for file %s (\"%s\")\n",
-                    filename, ext);
+                    "Failed to probe demuxer for file %s\n",
+                    filename);
             return DAV1D_ERR(ENOPROTOOPT);
         }
     }
